@@ -332,6 +332,7 @@ def omit_deep(omit_props, dct):
     # scalar
     return dct
 
+
 @curry
 def find_all_deep(predicate, dct):
     """
@@ -354,6 +355,7 @@ def find_all_deep(predicate, dct):
     # scalar
     return []
 
+
 @curry
 def replace_all_deep(mapping_func, dct):
     """
@@ -380,6 +382,7 @@ def replace_all_deep(mapping_func, dct):
     # scalar
     return dct
 
+
 @curry
 def pick(keys, obj):
     """
@@ -432,6 +435,7 @@ def pick_deep(pick_dct, dct):
     # scalar
     return dct
 
+
 @curry
 def pick_deep_all_array_items(pick_dct, dct):
     """
@@ -470,6 +474,7 @@ def pick_deep_all_array_items(pick_dct, dct):
     # scalar
     return dct
 
+
 @curry
 def map_with_obj_deep(f, dct):
     """
@@ -1200,6 +1205,7 @@ def index_by_and_map_items(f, map_item, list):
     :param list:
     :return:
     """
+
     def merge_result(f, acc, item):
         keys = f(item)
         return reduce(
@@ -1218,6 +1224,7 @@ def index_by_and_map_items(f, map_item, list):
         list
     )
 
+
 def index_by(f, list):
     """
     Ramda implementation of index_by. Concats items into the bucket key produced by f(item) for each item of list
@@ -1230,12 +1237,14 @@ def index_by(f, list):
 
     return index_by_and_map_items(f, lambda item: item, list)
 
+
 def unique(list1):
     # insert the list to the set
     list_set = set(list1)
     # convert the set to the list
     return list(list_set)
 
+
 def one_unique_or_raise(values):
     """
         Returns the single unique value in values or raise if there isn't one
@@ -1337,3 +1346,18 @@ def find_mapped_or(default, mapper, iterable):
         if mapped:
             return mapped
     return default
+
+
+def zip_with(func, lists):
+    """
+        Zip any number of lists into tuples of length len(sets). Map the tuples with func
+    :param func: A mapping function expecting len(sets) arguments
+    :param lists: Any number of lists
+    :return:
+    """
+    tuples = zip(*lists)
+    return map(
+        lambda args: func(*args),
+        tuples
+    )
+
